The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

# Changelog

## 0.1.1 (2024-11-14)


### Fixed

- Fixed map wrapper crash caused by not converting to master path


## 0.1.0 (2024-11-13)

First release. Compatible with `libmapstack`-based configurations in most circumstances.
